/*

  Simple ATtiny 85 Bluetooth Automation

  by: Pranav Rokde

  Bluetoooth Module ( HC-05 ) Connection

  RxD_(3) | IC Pin [2]  ---->  Tx Pin of Bluetooth Module
  TxD_(4) | IC Pin [3]  ---->  Rx Pin of Bluetooth Module

*/

#include<SoftwareSerial.h>

                   // Pin Mapping
#define RxD    3   // IC Pin [2]  Defining Rx Pin  || Tx Pin of Bluetooth Module
#define TxD    4   // IC Pin [3]  Defining Tx Pin  || Rx Pin of Bluetooth Module
#define RELAY  0   // IC Pin [5]  Defining Relay Connected to Load
#define BUTTON 2   // IC Pin [7]  Defining Push Button
#define BUZZER 1   // IC Pin [6]  Defining Buzzer

SoftwareSerial BT(RxD, TxD); // Rx|Tx

int RLY_FLAG = 0; // Relay Flag

int BUZZ_FLAG = 0; // Buzzer Flag

int BUTTONSTATE;                       // Current State of Button
int LASTBUTTONSTATE = HIGH;           // Previous State of Button
unsigned long LASTDEBOUNCETIME = 0;  // Last Toggle
unsigned long DEBOUNCEDELAY = 50;   // Debounce Time


void setup()
{

  pinMode(RELAY, OUTPUT);        // Set RELAY Pin as Output

  pinMode(BUZZER, OUTPUT);       // Set BUZZER Pin as Output

  pinMode(BUTTON, INPUT_PULLUP); // Set BUTTON Pin as Internally Pulled Up (HIGH)

  BT.begin(9600);                // Serial Begin for Bluetooth Module

}

void loop()
{

  BluetoothControl();  // Bluetooth Control Function

  ButtonControl();     // Push Button Function

  RelayControl();      // Relay Control Function

  BuzzerControl();     // Buzzer Control Function

}


void ButtonControl()
{

  int READING = digitalRead(BUTTON);   // Read Button

  if (READING != LASTBUTTONSTATE)      
  {
    LASTDEBOUNCETIME = millis();       
  }

  if ((millis() - LASTDEBOUNCETIME) > DEBOUNCEDELAY) {

    if (READING != BUTTONSTATE)
    {
      BUTTONSTATE = READING;

      if (BUTTONSTATE == LOW)
      {
        if ( RLY_FLAG == 0)  // Reading Relay Flag Status
        {

          BT.println('5');  // Send Data  
          RLY_FLAG = 1;     // Toggling Relay Flag

        }
        else if ( RLY_FLAG == 1) // Reading Relay Flag Status
        {

          BT.println('4');       // Send Data  
          RLY_FLAG = 0;          // Toggling Relay Flag

        }
      }
      delay(100); //Small delay
    }

  }

  LASTBUTTONSTATE = READING;    // Save the Reading

}




void BluetoothControl()
{

  if (BT.available())    // Serial Available to Recieve Data
  {

    char C = BT.read();  // Serial Read

    if (C == '1')        // Read Recieved Data 
    {
      RLY_FLAG = 1;      // Turning ON Relay Flag
    }

    if (C == '2')        // Read Recieved Data 
    {
      RLY_FLAG = 0;      // Turning OFF Relay Flag
    }

    if (C == '3')        // Read Recieved Data 
    {
      BUZZ_FLAG = 1;     // Turning ON Buzzer Flag
    }

    C = "";              //  Claer Serial Read

  }

}


void RelayControl()
{

  if ( RLY_FLAG == 0)          // Reading Relay Flag Status
  {
    digitalWrite(RELAY, LOW);  // Turning OFF RELAY
  }

  if ( RLY_FLAG == 1)          // Reading Relay Flag Status
  {
    digitalWrite(RELAY, HIGH); // Turning ON RELAY
  }

}


void BuzzerControl()
{

  if ( BUZZ_FLAG == 1)          // Reading Buzzer Flag Status
  {

    digitalWrite(BUZZER, HIGH); // Turning ON BUZZER

    delay(500);                 // Little Delay   

    digitalWrite(BUZZER, LOW);  // Turning OFF BUZZER
 
    BUZZ_FLAG = 0;              // Turning OFF Buzzer Flag
 
  }

}
